@@ -20,12 +20,13 @@
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
  * @copyright  2003-2008 PgPool Global Development Group
- * @version    CVS: $Id: fr.lang.php,v 1.22 2010/08/17 07:36:44 gleu Exp $
+ * @version    CVS: $Id$
  */
 
 $message = array(
     'lang' => 'fr',
     'strLang' => 'Français',
+    'descBackend_flag' => 'Autorise le failover et le détachement/attachement du noeud failover',
     'descBackend_hostname' => 'Le nom du vrai serveur PostgreSQL sur lequel pgpool va se connecter',
     'descBackend_port' => 'Le numéro de port du vrai serveur PostgreSQL',
     'descBackend_socket_dir' => 'Le répertoire du socket de PostgreSQL',
@@ -39,6 +40,7 @@ $message = array(
     'descConnection_cache' => 'Si vrai, met en cache les connexions vers PostgreSQL',
     'descConnection_life_time' => 'Durée de vie de chaque connexion inutilisée en secondes',
     'descDelay_threshold' => 'Si le serveur en standby a un lag plus important que delay_threshold, toutes les requêtes seront envoyés au serveur primaire seulement',
+    'descDebug_level' => 'Niveau de verbosité des messages de debogage',
     'descEnable_pool_hba' => 'Utilisation de l\'authentification basée sur l\'hôte',
     'descEnable_query_cache' => 'Mettre en place un cache des requêtes',
     'descFailover_command' => 'Commande à exécuter lors du détachement d\'un noeud',
@@ -46,6 +48,7 @@ $message = array(
     'descFailover_if_affected_tuples_mismatch' => 'Failover dû à un désaccord sur le nombre de lignes affectées par une commande UPDATE/DELETE',
     'descFail_over_on_backend_error' => 'Failover lors d\'une erreur de communication par socket avec le serveur',
 	'descClient_idle_limit_in_recovery' => 'Délai en secondes pour l\'attente d\'une requête d\'un client lors d\'une restauration',
+    'descFollow_master_command' => 'Commande à exécuter seulement après un failover du maître',
     'descHealth_check_period' => 'Spécifie l\'interval de la prochaine vérification du serveur. 0 correspond à une désactivation de la vérification, -1 correspond à pas d\'attente.',
     'descHealth_check_timeout' => 'Pgpool vérifie périodiquement l\'état des serveurs pour détecter les serveurs injoignables, parce que arrêter ou à cause d\'un problème réseau',
     'descHealth_check_user' => 'Nom de l\'utilisateur PostgreSQL pour la vérification de l\'état',
@@ -54,6 +57,7 @@ $message = array(
     'descListen_addresses' => 'Spécifie les adresses à écouter pour les connexions TCP/IP',
     'descLoad_balance_mode' => 'Réalise une répartition de charge pour les requêtes SELECT',
     'descLobj_lock_table' => 'Spécifie le verrou sur le nom de la table utilisé lors de la réécriture du lo_create en mode réplication',
+    'descLog_destination' => 'Où tracer',
     'descLog_connections' => 'Si vrai, les connexions entrantes seront tracées dans les journaux applicatifs',
     'descLog_standby_delay' => 'Fréquence pour tracer le lag du standby',
     'descLog_hostname' => 'Si vrai, le nom de l\'hôte sera affiché dans le statut ps et dans le journal applicatif si log_connections est activé',
@@ -77,12 +81,18 @@ $message = array(
     'descRecovery_1st_stage_command' => 'Commande de restauration à exécuter à la première étape',
     'descRecovery_2nd_stage_command' => 'Commande de restauration à exécuter à la deuxième étape',
     'descRecovery_timeout' => 'Attente en nombre de secondes pour terminer la restauration en ligne. 0 signifie sans attente.',
+    'descRelcache_expire' => 'Durée de vide du cache de relations en secondes',
     'descReplication_mode' => 'Configurer à vrai (true) si vous voulez utiliser la réplication',
     'descReplication_stop_on_mismatch' => 'Stopper le mode réplication en as de différence de données entre le maître et l\'esclave',
     'descReplicate_select' => 'Si vrai, réplique les requêtes SELECT. Si faux, les envoit seulement au maître',
     'descReplication_timeout' => 'Dans le mode de réplication non strict, il y un risque de verrou mortel',
     'descReset_query_list' => 'Commandes SQL séparées par des points-virgules à exécuter à la fin de la session',
     'descSocket_dir' => 'Le répertoire socket de connexion de pgpool',
+    'descSr_check_period' => 'Délai (en secondes) entre chaque vérification du lag de la réplication en flux',
+    'descSr_check_user' => 'Nom de l\'utilisateur PostgreSQL qui réalise la vérification du lag de réplication en flux',
+    'descSr_check_password' => 'Mot de passe de l\'utilisateur PostgreSQL qui réalise la vérification du lag de réplication en flux',
+    'descSyslog_facility' => 'Niveau syslog',
+    'descSyslog_ident' => 'Identification du programme pour syslog',
     'descSsl' => 'Connexion frontend',
     'descSsl_ca_cert' => 'Chemin vers le fichier contenant la clé privée SSL',
     'descSsl_ca_cert_dir' => 'Chemin vers le fichier contenant le certificat public SSL',
@@ -124,6 +134,7 @@ $message = array(
     'msgDetachConfirm' => 'Souhaitez-vous réellement détacher ce noeud ?',
     'msgReturnConfirm' => 'Souhaitez-vous réellement le retour de ce noeud ?',
     'msgRecoveryConfirm' => 'Souhaitez-vous réellement réintégrer ce noeud ?',
+    'msgRPromoteConfirm' => 'Souhaitez-vous réellement transformer ce noeud en noeud primaire ?',
     'strAdd' => 'Ajouter',
     'strAdminPassword' => 'Mot de passe',
     'strBack' => 'Retour',
@@ -159,7 +170,7 @@ $message = array(
     'strDetailInfo' => 'Informations détail',
     'strDisconnect' => 'Déconnexion',
     'strDistDefFunc'=> 'Nom de fonction distribué',
-    'strDown' => 'Bas',
+    'strDown' => 'Arrêté',
     'strError' => 'Erreur',
     'strErrorCode' => 'Code d\'erreur',
     'strErrorMessage' => 'Message d\'erreur',
@@ -181,9 +192,9 @@ $message = array(
     'strMeasures' => 'Mesures',
     'strNodeInfo' => 'Info. sur le noeud',
     'strNodeStatus' => 'Statut du noeud',
-    'strNodeStatus1' => 'Haut. Déconnexion.',
-    'strNodeStatus2' => 'Haut. Connexion.',
-    'strNodeStatus3' => 'Bas',
+    'strNodeStatus1' => 'En fonctionnement. Déconnexion.',
+    'strNodeStatus2' => 'En fonctionnement. Connexion.',
+    'strNodeStatus3' => 'Arrêté',
     'strNoNode' => 'Il n\'y a pas de noeud',
     'strOff' => 'Arrêté',
     'strOn' => 'Démarré',
@@ -215,6 +226,7 @@ $message = array(
     'strProcId' => 'Processus',
     'strProcInfo' => 'Info. processus',
     'strProcTime' => 'Début d\'exécution du processus',
+    'strPromote' => 'Promouvoir',
     'strProtocolMajorVersion' => 'Version majeure du protocole',
     'strProtocolNinorVersion' => 'Version mineure du protocole',
     'strQueryCache' => 'Cache des requêtes',
@@ -225,7 +237,7 @@ $message = array(
     'strRestart' => 'Redémarrer',
     'strRestartOption' => 'Options de redémarrage de pgpool',
     'strRestartPgpool' => 'Redémarrer pgpool',
-    'strReturn' => 'Renvoyer',
+    'strReturn' => 'Retour',
     'strRecovery' => 'Récupération',
     'strSchemaName' => 'Nom du schéma',
     'strSearch' => 'Rechercher',
@@ -244,7 +256,7 @@ $message = array(
     'strSystemDb' => 'Règle de partitionnement',
     'strTable' => 'Table',
     'strTypeList' => 'Saisir la liste des colonnes',
-    'strUp' => 'Haut',
+    'strUp' => 'En fonctionnement',
     'strUpdate' => 'Mettre à jour',
     'strValue' => 'Valeur',
     'strWeight' => 'Poids',
