@@ -238,7 +238,7 @@ $message = array(
     'strCmdPcpFile' => 'pcp.conf',
     'strCmdPgpoolFile' => 'pgpool.conf',
     'strColList' => '列的列表',
-    'strColName' => '用于分发的列名',
+    'strColName' => '用于分区的列名',
     'strCommon' => '公共',
     'strConnectionError' => '连接错误',
     'strConnTime' => '连接建立时间',
@@ -255,7 +255,7 @@ $message = array(
     'strDetail' => '细节',
     'strDetailInfo' => '详细信息',
     'strDisconnect' => '断开连接',
-    'strDistDefFunc'=> '分发函数名',
+    'strDistDefFunc'=> '分区函数名',
     'strDown' => '未启动',
     'strError' => '错误',
     'strErrorCode' => '错误码',
